==> eztrace_1.0.6.orig.tar.gz: eztrace-1.0.6/src/modules/mpi/mpi_funcs/mpi_bsend_init.c <==
/* -*- c-file-style: "GNU" -*- */
/*
 * Copyright (C) CNRS, INRIA, Universite Bordeaux 1, Telecom SudParis
 * See COPYING in top-level directory.
 */

#define _GNU_SOURCE 1
#define _REENTRANT

#include <unistd.h>
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <sys/time.h>
#include <sys/timeb.h>
#include <dlfcn.h>
#include <string.h>

#include "mpi.h"
#include "mpi_eztrace.h"
#include "mpi_ev_codes.h"
#include "eztrace.h"

static int MPI_Bsend_init_core(CONST void* buffer, int count, MPI_Datatype type,
                               int dest, int tag, MPI_Comm comm,
                               MPI_Request *req)
{
  return libMPI_Bsend_init(buffer, count, type, dest, tag, comm, req);
}

static void MPI_Bsend_init_epilog(CONST void* buffer, int count,
                                  MPI_Datatype type, int dest, int tag,
                                  MPI_Comm comm, MPI_Request *req)
{
  int size;
  MPI_Type_size(type, &size);
  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_BSEND_INIT, (app_ptr)buffer, count*size, dest);
  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_Info, tag, (app_ptr)comm, (app_ptr)req);
}

int MPI_Bsend_init(CONST void* buffer, int count, MPI_Datatype type, int dest,
                   int tag, MPI_Comm comm, MPI_Request *req)
{
  FUNCTION_ENTRY;
  int ret = MPI_Bsend_init_core(buffer, count, type, dest, tag, comm, req);
  MPI_Bsend_init_epilog(buffer, count, type, dest, tag, comm, (MPI_Fint*) req);
  return ret;
}

void mpif_bsend_init_(void*buffer, int*count, MPI_Fint*type, int*dest, int*tag,
                      MPI_Fint*comm, MPI_Fint *req, int*error) {
  FUNCTION_ENTRY;
  MPI_Datatype c_type = MPI_Type_f2c(*type);
  MPI_Comm c_comm = MPI_Comm_f2c(*comm);
  MPI_Request c_req = MPI_Request_f2c(*req);

  *error = MPI_Bsend_init_core(buffer, *count, c_type, *dest, *tag, c_comm,
                               &c_req);
  *req = MPI_Request_c2f(c_req);
  MPI_Bsend_init_epilog(buffer, *count, c_type, *dest, *tag, c_comm, req);
}

==> eztrace_1.1-2.orig.tar.gz: eztrace-1.1-2/src/modules/mpi/mpi_funcs/mpi_bsend_init.c <==
/* -*- c-file-style: "GNU" -*- */
/*
 * Copyright (C) CNRS, INRIA, Universite Bordeaux 1, Telecom SudParis
 * See COPYING in top-level directory.
 */

#define _GNU_SOURCE 1
#define _REENTRANT

#include <unistd.h>
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <sys/time.h>
#include <sys/timeb.h>
#include <dlfcn.h>
#include <string.h>

#include "mpi.h"
#include "mpi_eztrace.h"
#include "mpi_ev_codes.h"
#include "eztrace.h"

static int MPI_Bsend_init_core(CONST void* buffer, int count, MPI_Datatype type,
			       int dest, int tag, MPI_Comm comm,
			       MPI_Request *req)
{
  return libMPI_Bsend_init(buffer, count, type, dest, tag, comm, req);
}

static void MPI_Bsend_init_epilog(CONST void* buffer, int count,
				  MPI_Datatype type, int dest, int tag,
				  MPI_Comm comm, MPI_Request *req)
{
  int size;
  MPI_Type_size(type, &size);
  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_BSEND_INIT, (app_ptr)buffer, count*size, dest);
  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_Info, tag, (app_ptr)comm, (app_ptr)req);
}

int MPI_Bsend_init(CONST void* buffer, int count, MPI_Datatype type, int dest,
		   int tag, MPI_Comm comm, MPI_Request *req)
{
  FUNCTION_ENTRY;
  int ret = MPI_Bsend_init_core(buffer, count, type, dest, tag, comm, req);
  MPI_Bsend_init_epilog(buffer, count, type, dest, tag, comm, (void*) req);
  return ret;
}

void mpif_bsend_init_(void*buffer, int*count, MPI_Fint*type, int*dest, int*tag,
		      MPI_Fint*comm, MPI_Fint *req, int*error) {
  FUNCTION_ENTRY;
  MPI_Datatype c_type = MPI_Type_f2c(*type);
  MPI_Comm c_comm = MPI_Comm_f2c(*comm);
  MPI_Request c_req = MPI_Request_f2c(*req);

  *error = MPI_Bsend_init_core(buffer, *count, c_type, *dest, *tag, c_comm,
			       &c_req);
  *req = MPI_Request_c2f(c_req);
  MPI_Bsend_init_epilog(buffer, *count, c_type, *dest, *tag, c_comm, (MPI_Request *)req);
}
